function Event() {
}

Event._isPlaceHolder = function(title) {
    return title === "-" || title === "Amphi" || title === "Présentation";
};

Event.parseTitle = function(enex_event) {
    // titre//titre1: en général égaux à un espace près, mais :
    //  Journées Sportives Polytechniciennes//-
    //  Présentation //Amphi 4A - HEC présentation double diplome
    var titre = $.trim(enex_event.titre) || "";
    var titre1 = $.trim(enex_event.titre1) || "";

    if (titre === titre1) // Base case
        return titre;

    if (titre.length === 0 && titre1.length === 0)
        return "???";
    else if (titre.length > 3 && Event._isPlaceHolder(titre1))
        return titre;
    else if (titre1.length > 3 && Event._isPlaceHolder(titre))
        return titre1;
    else
        return titre1.length > titre.length ? titre1 : titre;
};

Event.fromEnexEvent = function(enex_event, id) {
    var event = new Event();

    event.id = id;
    event.sigle = enex_event.sigle;
    event.description = Event.parseTitle(enex_event);
    event.debut = moment(enex_event.start);
    event.fin = moment(enex_event.end);
    event.liste_profs = events.listeProfs(enex_event);
    event.liste_salles = utils.uniq(utils.splitCleanup(enex_event.sallesActivPedag));
    event.groupe = utils.trimNumber(enex_event.numGroupe);

    return event;
};

Event.fromDeserializedEvent = function(deserialized) {
    var event = new Event();

    $.extend(event, deserialized);
    event.debut = moment(event.debut);
    event.fin = moment(event.fin);

    return event;
};

Event.prototype.jour = function() {
    return this.debut.format("dddd");
};

Event.prototype.date = function() {
    return this.debut.format("DD/MM/YYYY");
};

Event.prototype.horaires = function() {
    return utils.formatTimePart(this.debut) + " - " + utils.formatTimePart(this.fin);
};

Event.prototype.profs = function() {
    return this.liste_profs.join(", ");
};

Event.prototype.salles = function() {
    return this.liste_salles.join(", ");
};

Event.prototype.couleur_cours = function() {
    return utils.colorHash(this.sigle);
};

Event.prototype.liens_profs = function() {
    return this.liste_profs.map(utils.profLink).join(', ');
};

Event.prototype.liens_salles = function() {
    return this.liste_salles.map(utils.salleLink).join(', ');
};

var events = {
    listeProfs: function(enex_event) {
        var profs = [].concat(utils.splitCleanup(enex_event.responOccurrence), utils.splitCleanup(enex_event.responActivPedag), utils.splitCleanup(enex_event.responGroupe));
        return utils.uniq(profs);
    },
    parseEnexEvents: function(json) {
        var enex_events = JSON.parse(json);
        var events = [];

        if (events !== null) {
            for (var event_id = 0; event_id < enex_events.length; event_id++) {
                events.push(Event.fromEnexEvent(enex_events[event_id], event_id));
            }
        }

        return events;
    },
    parseEvents: function(json) {
        var deserialized_events = JSON.parse(json);
        var events = [];

        for (event_id = 0; event_id < deserialized_events.length; event_id++) {
            var event = Event.fromDeserializedEvent(deserialized_events[event_id]);
            events.push(event);
        }

        return events;
    }
};