var utils = {
    filter: function(events, condition) {
        return events === null ? [] : $.grep(events, condition);
    },
    formatTimePart: function(date) {
        return date.format("HH:mm");
    },
    formatDayPart: function(date) {
        return date.format("DD/MM (dddd)");
    },
    formatDate: function(period_type, date_reference) {
        if (period_type === "day") {
            var same_day = (date_reference.startOf('day').diff(moment().startOf('day')) === 0); //if (same_day) return "aujourd'hui";
            return (same_day ? "<strong>" : "") + utils.formatDayPart(date_reference) + (same_day ? "</strong>" : "");
        } else {
            var monday = date_reference.clone().day(date_reference.day() === 0 ? -6 : 1);
            return "Semaine du " + monday.format("DD/MM");
        }
    },
    uniq: function(arr) {
        arr.sort();
        var uniq_elements = [];

        var prev;
        for (var pos = 0; pos < arr.length; pos++) {
            var elem = arr[pos];
            if (elem !== prev) {
                uniq_elements.push(elem);
                prev = elem;
            }
        }

        return uniq_elements;
    },
    splitCleanup: function(str) {
        var in_arr = str.split(",");
        var out_arr = [];

        for (var pos = 0; pos < in_arr.length; pos++) {
            var entry = $.trim(in_arr[pos]);
            if (entry !== "-")
                out_arr.push(entry);
        }

        return out_arr;
    },
    dateRange: function(date) {
        var start = date.clone().day(-7 * 2).hour(23).minute(0);
        var end = date.clone().day(+7 * 3).hour(23).minute(0);
        return {"start": start, "end": end};
    },
    fadeIn: function() {
        $(this).animate({opacity: 1}, 100);
    },
    fadeOut: function() {
        $(this).animate({opacity: 0}, 100);
    },
    decimalToHex: function(dec) {
        var hex = Number(dec).toString(16);
        while (hex.length < 2)
            hex = "0" + hex;
        return hex;
    },
    colorHash: function(str) {
        var hash = 0;

        for (var pos = 0; pos < str.length; pos++) {
            var char = str.charCodeAt(pos) ^ str.charCodeAt(str.length - pos - 1);
            hash = ((hash << 5) - hash) + char;
            hash = hash & hash; // Convert to 32bit integer
        }

        if (hash < 0)
            hash = -hash;

        var mask = 0xff;// - (1 << 7);
        return "#" + utils.decimalToHex(hash & mask) + utils.decimalToHex((hash >> 8) & mask) + utils.decimalToHex((hash >> 16) & mask);
    },
    trimNumber: function(num_str) {
        var num = Number(num_str);
        return isNaN(num) ? num_str : String(num);
    },
    toEmailAddress: function(name) {
        return removeDiacritics(name).replace(" ", ".").toLowerCase() + "@polytechnique.edu";
    },
    profLink: function(name) {
        return '<a class="stalk link">' + name + '</a> (<a class="mail link" href="mailto:' + utils.toEmailAddress(name) + '">mail</a>)';
    },
    salleLink: function(str) {
        var id = map.lookupPoi(str);
        if (id > -1)
            return '<a class="poi link" data-poi-id="' + id + '">' + str + '</a>';
        else
            return str;
    },
    stopPropagation: function(tap_event) {
        if (typeof tap_event !== 'undefined')
            tap_event.stopPropagation();
    },
    navigateTo: function(url) {
        if (typeof navigator.app !== "undefined")
            navigator.app.loadUrl(url, {openExternal: true});
        else
            window.open(url, '_system', '');
    },
    hideCallback: function() {
        $(this).css("display", "none");
        tryUnregBackKey();
    },
    hideElement: function(elem_id) {
        $(elem_id).animate({"opacity": 0}, 100, utils.hideCallback);
    },
    isVisible: function(elem_id) {
        return $(elem_id).css("display") !== "none";
    }
};